@@ -102,10 +102,10 @@ class SimpleConsumer:
                 raise tTransportException
 
         # update scheduleInfocache when request have been transfered and talos auto location was set up
-        if self.scheduleInfoCache.get_is_auto_location()\
-                and self.scheduleInfoCache and getMessageResponse.isTransfer:
-            self.logger.info("request has been transfered when talos auto location set up, refresh scheduleInfo")
-            self.scheduleInfoCache.update_schedule_info_cache()
+        if self.scheduleInfoCache and self.scheduleInfoCache.get_is_auto_location():
+            if getMessageResponse and getMessageResponse.isTransfer:
+                self.logger.info("request has been transfered when talos auto location set up, refresh scheduleInfo")
+                self.scheduleInfoCache.update_schedule_info_cache()
 
         messageAndOffsetList = Compression().decompress(getMessageResponse.messageBlocks,
                                                         getMessageResponse.unHandledMessageNumber)
