@@ -15,6 +15,8 @@ class BufferedMessageCount:
         self._maxBufferedMsgBytes = maxBufferedMsgBytes
         self._bufferedMsgNumber = 0
         self._bufferedMsgBytes = 0
+        self.increaseLock = threading.Lock()
+        self.decreaseLock = threading.Lock()
         self.synchronizedLock = threading.Lock()
 
     def get_buffered_msg_number(self):
@@ -23,15 +25,17 @@ class BufferedMessageCount:
     def get_buffered_msg_bytes(self):
         return self._bufferedMsgBytes
 
-    @synchronized
     def increase(self, diffBufferedMsgNumber, diffBufferedMsgBytes):
+        self.increaseLock.acquire()
         self._bufferedMsgNumber += diffBufferedMsgNumber
         self._bufferedMsgBytes += diffBufferedMsgBytes
+        self.increaseLock.release()
 
-    @synchronized
     def decrease(self, diffBufferedMsgNumber, diffBufferedMsgBytes):
+        self.decreaseLock.acquire()
         self._bufferedMsgNumber -= diffBufferedMsgNumber
         self._bufferedMsgBytes -= diffBufferedMsgBytes
+        self.decreaseLock.release()
 
     @synchronized
     def is_empty(self):
