@@ -6,8 +6,10 @@
 
 from talos.thrift.topic.ttypes import GetTopicAttributeRequest
 from talos.thrift.topic.ttypes import GetTopicAttributeResponse
+from talos.thrift.topic.ttypes import GetDescribeInfoRequest
 from talos.thrift.message.ttypes import MessageType
 from talos.client.Constants import Constants
+from talos.client.ScheduleInfoCache import ScheduleInfoCache
 from atomic import AtomicLong
 from talos.producer.BufferedMessageCount import BufferedMessageCount
 from talos.producer.UserMessage import UserMessage
@@ -67,8 +69,8 @@ class TalosProducer(object):
         if topicTalosResourceName:
             self.topicTalosResourceName = topicTalosResourceName
         else:
-            self.topicTalosResourceName = self.talosAdmin.get_topic_attribute(
-                GetTopicAttributeRequest(topicName=self.topicName))
+            self.topicTalosResourceName = self.talosAdmin.get_describe_info(
+                GetDescribeInfoRequest(self.topicName))
         self.partitioner = partitioner
         self.topicAbnormalCallback = topicAbnormalCallback
         self.userMessageCallback = userMessageCallback
@@ -88,6 +90,12 @@ class TalosProducer(object):
         self.create_partition_senderLock = threading.Lock()
         self.release_partition_senderLock = threading.Lock()
 
+        # get scheduleInfo
+        self.scheduleInfoCache = ScheduleInfoCache().get_schedule_info_cache(
+            topicTalosResourceName=self.topicTalosResourceName.topicTalosResourceName,
+            talosClientConfig=producerConfig,
+            messageClient=self.talosClientFactory.new_message_client(),
+            talosClientFactory=self.talosClientFactory)
         self.falconWriter = FalconWriter(falconUrl=self.talosProducerConfig.get_falcon_url())
 
         # getTopicTalosResourceName(producerConfig, credential);
@@ -291,6 +299,7 @@ class TalosProducer(object):
             value.shutdown()
         self.partitionCheckExecutor.cancel()
         self.producerMonitorThread.cancel()
+        self.scheduleInfoCache.shut_down(self.topicTalosResourceName)
 
     def adjust_partition_sender(self, newPartitionNum=None):
         if self.partitionNumber < newPartitionNum:
